@@ -6,122 +6,154 @@ use strict;
 
 # Warning: There is another version line, in t/02.main.t.
 
-our $VERSION = '2.21';
+our $VERSION = '2.25';
 
 BEGIN {
-	require 5.008001;
+	require 5.008001; # For the utf8 stuff.
 	$Config::Tiny::errstr  = '';
 }
 
-# Create an empty object
-sub new { bless {}, shift }
+# Create an empty object.
 
-# Create an object from a file
-sub read {
-	my $class = ref $_[0] ? ref shift : shift;
-	my $file  = shift or return $class->_error('No file name provided');
+sub new { return bless {}, shift }
+
+# Create an object from a file.
+
+sub read
+{
+	my($class)           = ref $_[0] ? ref shift : shift;
+	my($file, $encoding) = @_;
+
+	return $class -> _error('No file name provided') if (! defined $file || ($file eq '') );
 
 	# Slurp in the file.
 
-	my $encoding = shift;
-	$encoding    = $encoding ? "<:$encoding" : '<';
-	local $/     = undef;
+	$encoding = $encoding ? "<:$encoding" : '<';
+	local $/  = undef;
 
-	open( CFG, $encoding, $file ) or return $class->_error( "Failed to open file '$file' for reading: $!" );
+	open( CFG, $encoding, $file ) or return $class -> _error( "Failed to open file '$file' for reading: $!" );
 	my $contents = <CFG>;
 	close( CFG );
 
 	return $class -> _error("Reading from '$file' returned undef") if (! defined $contents);
 
-	return $class->read_string( $contents );
-}
+	return $class -> read_string( $contents );
+
+} # End of read.
+
+# Create an object from a string.
+
+sub read_string
+{
+	my($class) = ref $_[0] ? ref shift : shift;
+	my($self)  = bless {}, $class;
 
-# Create an object from a string
-sub read_string {
-	my $class = ref $_[0] ? ref shift : shift;
-	my $self  = bless {}, $class;
 	return undef unless defined $_[0];
 
-	# Parse the file
+	# Parse the file.
+
 	my $ns      = '_';
 	my $counter = 0;
-	foreach ( split /(?:\015{1,2}\012|\015|\012)/, shift ) {
+
+	foreach ( split /(?:\015{1,2}\012|\015|\012)/, shift )
+	{
 		$counter++;
 
-		# Skip comments and empty lines
+		# Skip comments and empty lines.
+
 		next if /^\s*(?:\#|\;|$)/;
 
-		# Remove inline comments
+		# Remove inline comments.
+
 		s/\s\;\s.+$//g;
 
-		# Handle section headers
-		if ( /^\s*\[\s*(.+?)\s*\]\s*$/ ) {
+		# Handle section headers.
+
+		if ( /^\s*\[\s*(.+?)\s*\]\s*$/ )
+		{
 			# Create the sub-hash if it doesn't exist.
 			# Without this sections without keys will not
 			# appear at all in the completed struct.
+
 			$self->{$ns = $1} ||= {};
+
 			next;
 		}
 
-		# Handle properties
-		if ( /^\s*([^=]+?)\s*=\s*(.*?)\s*$/ ) {
+		# Handle properties.
+
+		if ( /^\s*([^=]+?)\s*=\s*(.*?)\s*$/ )
+		{
 			$self->{$ns}->{$1} = $2;
+
 			next;
 		}
 
-		return $self->_error( "Syntax error at line $counter: '$_'" );
+		return $self -> _error( "Syntax error at line $counter: '$_'" );
 	}
 
-	$self;
+	return $self;
 }
 
-# Save an object to a file
-sub write {
-	my $self     = shift;
-	my $file     = shift or return $self->_error('No file name provided');
-	my $encoding = shift;
-	$encoding    = $encoding ? ">:$encoding" : '>';
+# Save an object to a file.
+
+sub write
+{
+	my($self)            = shift;
+	my($file, $encoding) = @_;
+
+	return $self -> _error('No file name provided') if (! defined $file or ($file eq '') );
+
+	$encoding = $encoding ? ">:$encoding" : '>';
+
+	# Write it to the file.
+
+	my($string) = $self->write_string;
 
-	# Write it to the file
-	my $string = $self->write_string;
 	return undef unless defined $string;
-	open( CFG, $encoding, $file ) or return $self->_error(
-		"Failed to open file '$file' for writing: $!"
-		);
+
+	open( CFG, $encoding, $file ) or return $self->_error("Failed to open file '$file' for writing: $!");
 	print CFG $string;
 	close CFG;
 
 	return 1;
-}
 
-# Save an object to a string
-sub write_string {
-	my $self = shift;
+} # End of write.
 
-	my $contents = '';
-	foreach my $section ( sort { (($b eq '_') <=> ($a eq '_')) || ($a cmp $b) } keys %$self ) {
+# Save an object to a string.
+
+sub write_string
+{
+	my($self)     = shift;
+	my($contents) = '';
+
+	for my $section ( sort { (($b eq '_') <=> ($a eq '_')) || ($a cmp $b) } keys %$self )
+	{
 		# Check for several known-bad situations with the section
 		# 1. Leading whitespace
 		# 2. Trailing whitespace
-		# 3. Newlines in section name
-		return $self->_error(
-			"Illegal whitespace in section name '$section'"
-		) if $section =~ /(?:^\s|\n|\s$)/s;
+		# 3. Newlines in section name.
+
+		return $self->_error("Illegal whitespace in section name '$section'") if $section =~ /(?:^\s|\n|\s$)/s;
+
 		my $block = $self->{$section};
 		$contents .= "\n" if length $contents;
 		$contents .= "[$section]\n" unless $section eq '_';
-		foreach my $property ( sort keys %$block ) {
-			return $self->_error(
-				"Illegal newlines in property '$section.$property'"
-			) if $block->{$property} =~ /(?:\012|\015)/s;
+
+		for my $property ( sort keys %$block )
+		{
+			return $self->_error("Illegal newlines in property '$section.$property'") if $block->{$property} =~ /(?:\012|\015)/s;
+
 			$contents .= "$property=$block->{$property}\n";
 		}
 	}
 
-	$contents;
-}
+	return $contents;
+
+} # End of write_string.
+
+# Error handling.
 
-# Error handling
 sub errstr { $Config::Tiny::errstr }
 sub _error { $Config::Tiny::errstr = $_[1]; undef }
 
@@ -183,11 +215,9 @@ Config::Tiny - Read/Write .ini style files with as little code as possible
 =head1 DESCRIPTION
 
 C<Config::Tiny> is a Perl class to read and write .ini style configuration
-files with as little code as possible, reducing load time and memory
-overhead.
+files with as little code as possible, reducing load time and memory overhead.
 
-Most of the time it is accepted that Perl applications use a lot
-of memory and modules.
+Most of the time it is accepted that Perl applications use a lot of memory and modules.
 
 The C<*::Tiny> family of modules is specifically intended to provide an ultralight alternative
 to the standard modules.
@@ -217,7 +247,7 @@ Lines starting with C<'#'> or C<';'> are considered comments and ignored,
 as are blank lines.
 
 When writing back to the config file, all comments, custom whitespace,
-and the ordering of your config file elements is discarded. If you need
+and the ordering of your config file elements are discarded. If you need
 to keep the human elements of a config when writing back, upgrade to
 something better, this module is not for you.
 
@@ -280,16 +310,50 @@ Generates the file content for the object and returns it as a string.
 
 =head1 FAQ
 
+=head2 What happens if a key is repeated?
+
+The last value is retained, overwriting any previous values.
+
+See t/06.repeat.key.t.
+
 =head2 Why can't I put comments at the ends of lines?
 
-Because a line like:
+=over 4
+
+=item o The # char is only introduces a comment when it's at the start of a line.
+
+So a line like:
 
 	key=value # A comment
 
-Sets key to 'value # A comment' :-(.
+Sets key to 'value # A comment', which, presumably, you did not intend.
 
 This conforms to the syntax discussed in L</CONFIGURATION FILE SYNTAX>.
 
+=item o Comments matching /\s\;\s.+$//g; are ignored.
+
+This means you can't preserve the suffix using:
+
+	key = Prefix ; Suffix
+
+Result: key is now 'Prefix'.
+
+But you can do this:
+
+	key = Prefix;Suffix
+
+Result: key is now 'Prefix;Suffix'.
+
+Or this:
+
+	key = Prefix; Suffix
+
+Result: key is now 'Prefix; Suffix'.
+
+=back
+
+See t/07.trailing.comment.t.
+
 =head2 Why can't I omit the '=' signs?
 
 E.g.:
@@ -330,9 +394,11 @@ Or even, a bit ridiculously:
 
 	my($value) = ${Config::Tiny -> read_string('alpha=bet')}{_}{alpha}; # $value is 'bet'.
 
-=head1 CAVEATS
+=head2 Can I use a file called '0' (zero)?
 
-=head2 Unsupported Section Headers
+Yes. See t/05.zero.t (test code) and t/0 (test data).
+
+=head1 CAVEATS
 
 Some edge cases in section headers are not supported, and additionally may not
 be detected when writing the config file.
@@ -341,11 +407,9 @@ Specifically, section headers with leading whitespace, trailing whitespace,
 or newlines anywhere in the section header, will not be written correctly
 to the file and may cause file corruption.
 
-=head2 Setting an option more than once
+=head1 Repository
 
-C<Config::Tiny> will only recognize the first time an option is set in a
-config file. Any further attempts to set the same option later in the config
-file are ignored.
+L<https://github.com/ronsavage/Config-Tiny.git>
 
 =head1 SUPPORT
 
